const chalk = require('chalk')
const frame = require('./frame')
const googleTranslate = require('./google')
const youdaoTranslate = require('./youdao')
const { isChinese, isEnglish } = require('./utils')

async function dict (word, options) {
  let source = options.source || 'google'
  let type, title;
  if (isChinese(word)) {
    title = '[中] >> [英]';
    // console.log('[中] >> [英]')
    type = 'isChinese';
  } else if (isEnglish(word)) {
    title = '[英] >> [中]';
    type = 'isEnglish';
    // console.log('[英] >> [中]')
  } else {
    console.log('无法识别，暂不处理')
    return;
  }

  let translationResult;
  if (source === 'google') {
    // console.log('使用 google 翻译')
    translationResult = await googleTranslate({
      type,
      word
    });
  } else {
    // console.log('使用 youdao 翻译')
    translationResult = await youdaoTranslate({
      type,
      word
    });
  }

  // 嵌入frame layout
  frame(title, translationResult);
}

module.exports = (word, options) => {
  dict(word, options).catch(err => {
    process.exit(1)
  })
}